.. _publications:

***********************************
Publications related to Cratermaker
***********************************

Below is a list of publications and presentations related to the Cratermaker project. You can view them online or download the PDFs for offline reading.


- Minton, D.A. (2024) Cratermaker: A Modern Python-Based Cratered Terrain Evolution Model. LPSC 55 #2462. `Abstract <https://www.hou.usra.edu/meetings/lpsc2024/pdf/2462.pdf>`_  `Poster <https://www.datadepot.rcac.purdue.edu/daminton/Minton_LPSC2024-Cratermaker.pdf>`_
